emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/vc-svn.el


From: Bill Wohler
Subject: [Emacs-diffs] Changes to emacs/lisp/vc-svn.el
Date: Tue, 13 Dec 2005 00:48:05 +0000

Index: emacs/lisp/vc-svn.el
diff -u emacs/lisp/vc-svn.el:1.22 emacs/lisp/vc-svn.el:1.23
--- emacs/lisp/vc-svn.el:1.22   Mon Nov 14 04:33:03 2005
+++ emacs/lisp/vc-svn.el        Tue Dec 13 00:48:04 2005
@@ -114,13 +114,18 @@
                                           (file-name-directory file)))
     (with-temp-buffer
       (cd (file-name-directory file))
-      (condition-case nil
-         (vc-svn-command t 0 file "status" "-v")
-       ;; Some problem happened.  E.g. We can't find an `svn' executable.
-        ;; We used to only catch `file-error' but when the process is run on
-        ;; a remote host via Tramp, the error is only reported via the
-        ;; exit status which is turned into an `error' by vc-do-command.
-       (error nil))
+        (condition-case nil
+            ;; Save configuration since vc-do-command calls pop-to-buffer on
+            ;; error (such as visiting a Subversion-controlled file that you
+            ;; don't have permission to edit). This causes later problems
+            ;; during registration.
+            (save-window-excursion
+              (vc-svn-command t 0 file "status" "-v"))
+          ;; Some problem happened.  E.g. We can't find an `svn' executable.
+          ;; We used to only catch `file-error' but when the process is run on
+          ;; a remote host via Tramp, the error is only reported via the
+          ;; exit status which is turned into an `error' by vc-do-command.
+          (error nil))
       (vc-svn-parse-status t)
       (eq 'SVN (vc-file-getprop file 'vc-backend)))))
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]